Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2449)

Unified Diff: content/renderer/pepper/resource_converter.cc

Issue 442383002: Move storage-related files from webkit/ to new top-level directory storage/ (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: . Created 6 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/renderer/pepper/resource_converter.cc
diff --git a/content/renderer/pepper/resource_converter.cc b/content/renderer/pepper/resource_converter.cc
index 8192f0c7a413e1aa0cbf171a357123b3bbc8adae..80236a5b67771de519ac2dac341056affc1ab111 100644
--- a/content/renderer/pepper/resource_converter.cc
+++ b/content/renderer/pepper/resource_converter.cc
@@ -22,7 +22,7 @@
#include "third_party/WebKit/public/web/WebDOMFileSystem.h"
#include "third_party/WebKit/public/web/WebDOMMediaStreamTrack.h"
#include "third_party/WebKit/public/web/WebLocalFrame.h"
-#include "webkit/common/fileapi/file_system_util.h"
+#include "storage/common/fileapi/file_system_util.h"
using ppapi::ResourceVar;
@@ -57,23 +57,23 @@ PP_FileSystemType WebFileSystemTypeToPPAPI(blink::WebFileSystem::Type type) {
}
}
// Converts a fileapi::FileSystemType to a blink::WebFileSystemType.
// Returns true on success, false if |type| does not correspond to a
// WebFileSystemType.
bool FileApiFileSystemTypeToWebFileSystemType(
- fileapi::FileSystemType type,
+ storage::FileSystemType type,
blink::WebFileSystemType* result_type) {
switch (type) {
- case fileapi::kFileSystemTypeTemporary:
+ case storage::kFileSystemTypeTemporary:
*result_type = blink::WebFileSystemTypeTemporary;
return true;
- case fileapi::kFileSystemTypePersistent:
+ case storage::kFileSystemTypePersistent:
*result_type = blink::WebFileSystemTypePersistent;
return true;
- case fileapi::kFileSystemTypeIsolated:
+ case storage::kFileSystemTypeIsolated:
*result_type = blink::WebFileSystemTypeIsolated;
return true;
- case fileapi::kFileSystemTypeExternal:
+ case storage::kFileSystemTypeExternal:
*result_type = blink::WebFileSystemTypeExternal;
return true;
default:
@@ -126,11 +126,11 @@ bool ResourceHostToDOMFileSystem(
v8::Handle<v8::Value>* dom_file_system) {
GURL root_url = file_system_host->GetRootUrl();
GURL origin;
- fileapi::FileSystemType type;
+ storage::FileSystemType type;
base::FilePath virtual_path;
- fileapi::ParseFileSystemSchemeURL(root_url, &origin, &type, &virtual_path);
+ storage::ParseFileSystemSchemeURL(root_url, &origin, &type, &virtual_path);
- std::string name = fileapi::GetFileSystemName(origin, type);
+ std::string name = storage::GetFileSystemName(origin, type);
blink::WebFileSystemType blink_type;
if (!FileApiFileSystemTypeToWebFileSystemType(type, &blink_type))
return false;
@@ -57,23 +57,23 @@ PP_FileSystemType WebFileSystemTypeToPPAPI(blink::WebFileSystem::Type type) {
}
}
-// Converts a fileapi::FileSystemType to a blink::WebFileSystemType.
+// Converts a storage::FileSystemType to a blink::WebFileSystemType.
// Returns true on success, false if |type| does not correspond to a
// WebFileSystemType.
« no previous file with comments | « content/renderer/pepper/pepper_file_system_host.cc ('k') | content/renderer/renderer_webkitplatformsupport_impl.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698